#!/bin/bash

base_dir="$(dirname "${BASH_SOURCE[0]}")"
lib_dir="$base_dir/lib/"
big_yotta_rest="/opt/BigYottaHeadless/BigYottaHeadless"
big_yotta_web="/opt/BigYottaHeadless/BigYottaWeb"
web_port=2000
rest_port=9001
ok=" [ok]"
failed=" [failed] timeout"

command="$1"


checkPortStarted()
{
    lsof -i:$rest_port | grep "$big_yotta_rest" >/dev/null && lsof -i:$web_port | grep "$big_yotta_rest" >/dev/null;
}
checkBYStarted()
{
    pgrep -f "$big_yotta_rest" >/dev/null && pgrep -f "$big_yotta_web" >/dev/null
}
checkBYStopped()
{
    if checkBYStarted; then
        return 1;
    else
        return 0;
    fi;
}
checkStart()
{
    echo -n "Starting Big Yotta ";
    if timeout 180s bash -c "until lsof -i:$rest_port | grep "TCP" >/dev/null && lsof -i:$web_port | grep "TCP" >/dev/null; do echo -n '.' & sleep 1;  done;"; then
        echo "$ok";
    else
        echo "$failed";s
        stop;
    fi;
}
checkStop()
{
    echo -n "Stopping Big Yotta ";

    until checkBYStopped; do
        echo -n "." & sleep 1;
    done;
    echo "$ok";
}
start() 
{
    if checkBYStarted; then echo "Big Yotta is currently running. Use restart"; return; fi;
    $big_yotta_rest > ~/.bigyotta/rest-server.log 2>/dev/null&
    $big_yotta_web > ~/.bigyotta/web-server.log 2>/dev/null&
    checkStart;
}
stop()
{
    pkill -15 -f "$big_yotta_rest";
    pkill -15 -f "$big_yotta_web";
    checkStop;
}
restart()
{
    stop;
    start;
}
printHelp()
{
cat << EOF
usage:
    start - start big-yotta
    stop - stop big-yotta
    restart - restart big-yotta
EOF
}
if [ -z "$command" ] ; then
    echo "Command missing";
    printHelp;
elif [ "$command" == "start" ] ; then
    start;
elif [ "$command" == "stop" ] ; then
    stop;
elif [ "$command" == "restart" ] ; then
    restart;
else 
    printHelp;
fi
